# We map the PrintScreen key (useless) and Alt+AltGr to the Compose key...
# A really useful thing not found on normal keyboards. :/
#
# (c) 2001 Bernhard Rosenkränzer <bero@arklinux.org>

keycode  99 = Compose		# SysRq/PrintScrn
keycode 100 = AltGr		
alt keycode 100 = Compose
